@@ -11,7 +11,14 @@ Copyright (C) 2023  Valentin Goldité
     DISTRIBUTION and PRIVATE USE as long as the original license is
     include as well as this copy right notice.
 """
+# pylint: disable=wrong-import-position
 
-from logml.logger import Logger
+from rich.console import Console
 
-__all__ = ['Logger']
+from logml._version import __version__, __version_tuple__
+
+RICH_CONSOLE = Console()
+
+from logml.logger import Logger  # noqa: E402
+
+__all__ = ["__version__", "__version_tuple__", "Logger", 'RICH_CONSOLE']
